@@ -3,9 +3,11 @@ import canvasapi
 import canvaslms.cli.courses as courses
 import canvaslms.hacks.canvasapi
 import csv
-import pydoc
+import os
 import pypandoc
 import re
+import rich.console
+import rich.markdown
 import sys
 
 def add_assignment_option(parser, ungraded=True, required=False):
@@ -73,9 +75,26 @@ def filter_assignments_by_group(assignment_group, assignments):
       assignment.assignment_group = assignment_group
       yield assignment
 def assignment_command(config, canvas, args):
+  console = rich.console.Console()
+
   assignment_list = process_assignment_option(canvas, args)
   for assignment in assignment_list:
-    pydoc.pager(format_assignment(assignment))
+    output = format_assignment(assignment)
+
+    if sys.stdout.isatty():
+      pager = ""
+      if "MANPAGER" in os.environ:
+        pager = os.environ["MANPAGER"]
+      elif "PAGER" in os.environ:
+        pager = os.environ["PAGER"]
+
+      styles = False
+      if "less" in pager and ("-R" in pager or "-r" in pager):
+        styles = True
+      with console.pager(styles=styles, links=True):
+        console.print(rich.markdown.Markdown(output))
+    else:
+      print(output)
 def format_assignment(assignment):
   """Returns an assignment formatted for the terminal"""
   instruction = pypandoc.convert_text(
