@@ -220,8 +220,6 @@ def add_user_option_wo_depends(parser, required=False):
   Adds the -u option to argparse parser,
   without adding other required options
   """
-  user_parser = parser.add_argument_group("filter by user")
-
   help="Filter users on name, login ID or Canvas ID by user_regex"
   options = {"required": required}
   if not required:
@@ -230,7 +228,7 @@ def add_user_option_wo_depends(parser, required=False):
   else:
     help += ", required: use '.*' to match all students"
 
-  user_parser.add_argument("-u", "--user", metavar="user_regex",
+  parser.add_argument("-u", "--user", metavar="user_regex",
     help=help, **options)
 
 def add_user_option(parser, required=False):
@@ -263,12 +261,16 @@ def add_group_category_option(parser):
   add_group_category_option_wo_depends(parser)
 
 def add_group_option_wo_depends(parser):
-  """Adds group filtering option to argparse parser,
-  without adding required options"""
+  """
+  Adds group filtering option to argparse parser,
+  without adding required options
+  """
+  try:
+    add_group_category_option_wo_depends(parser)
+  except argparse.ArgumentError:
+    pass
 
-  group_parser = parser.add_argument_group("filter by group")
-  add_group_category_option_wo_depends(group_parser)
-  group_parser.add_argument("-G", "--group", metavar="group_regex",
+  parser.add_argument("-G", "--group", metavar="group_regex",
     required=False,
     help="Filters groups whose name match group_regex")
 
@@ -294,15 +296,24 @@ def process_group_options(canvas, args):
   return list(filter_groups(
     course_list,
     args.group))
-def add_user_or_group_option(parser):
+def add_user_or_group_option(parser, required=False):
   """Adds user and group options as mutually exclusive options to parser"""
   try:
     courses.add_course_option(parser)
   except argparse.ArgumentError:
     pass
 
-  add_user_option_wo_depends(parser)
-  add_group_option_wo_depends(parser)
+  parser = parser.add_mutually_exclusive_group(required=required)
+
+  try:
+    add_user_option_wo_depends(parser)
+  except argparse.ArgumentError:
+    pass
+
+  try:
+    add_group_option_wo_depends(parser)
+  except argparse.ArgumentError:
+    pass
 
 def process_user_or_group_option(canvas, args):
   """Returns a list of users, filtered either by user regex or by groups"""
